import tempfile, signal, os

GKSU_PATH = "/usr/bin/gksu"
SYNAPTIC_PATH = "/usr/sbin/synaptic"
SYNAPTIC_DESKTOP = "/usr/share/applications/synaptic.desktop"
SCP_PATH = "/usr/bin/system-config-printer"
SCP_DESKTOP = "/usr/share/applications/system-config-printer.desktop"

children_tmpfiles = {}

def child_reap_cb (signum, stack):
    (pid, status) = os.wait ()
    if pid in children_tmpfiles:
        os.remove (children_tmpfiles[pid])
        del children_tmpfiles[pid]

def can_install_packages ():
    return os.access (SYNAPTIC_PATH, os.X_OK)

def install_packages (pkglist):
    (fd, tmpname) = tempfile.mkstemp(prefix="s-c-p_synaptic_")
    f = os.fdopen (fd, "w")
    for pkg in pkglist:
        f.write('%s\tinstall\n'%pkg)
    f.close()
    signal.signal (signal.SIGCHLD, child_reap_cb)
    pid = os.spawnl (os.P_NOWAIT, GKSU_PATH, "gksu", "--description",
                     SYNAPTIC_DESKTOP, "--", SYNAPTIC_PATH,
                     "--hide-main-window", "--non-interactive",
                     "-o", "Synaptic::closeZvt=true",
                     "--set-selections-file", tmpname)
    children_tmpfiles[pid] = tmpname

def run_config_tool (args):
    signal.signal (signal.SIGCHLD, child_reap_cb)
    os.spawnv (os.P_NOWAIT, GKSU_PATH, ["gksu", "--description",
               SCP_DESKTOP, "--", SCP_PATH ] + args)
